# SAP Cloud ALM Integration for SAP Discovery
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/sap-discovery-cloud-alm#overview)
  * [Benefits](https://help.sap.com/docs/leanix/ea/sap-discovery-cloud-alm#benefits)
  * [Scope](https://help.sap.com/docs/leanix/ea/sap-discovery-cloud-alm#scope)
  * [Limitations](https://help.sap.com/docs/leanix/ea/sap-discovery-cloud-alm#limitations)
  * [Detailed Guides](https://help.sap.com/docs/leanix/ea/sap-discovery-cloud-alm#detailed-guides)


Automatically discover and inventory SAP systems, services, and integration flows, ensuring an up-to-date overview of your SAP landscape.
